Struct HWNDWrapper
struct HWNDWrapper {
hwdn: HWND,
}Expand description
Hacky wrapper around a window handle.
As we cannot implement foreign traits for foreign structs we introduce this wrapper to implement Send for [HWND].
Fields
hwdn: HWNDTrait Implementations
impl Debug for HWNDWrapper
impl Debug for HWNDWrapper
impl PartialEq for HWNDWrapper
impl PartialEq for HWNDWrapper
impl Eq for HWNDWrapper
impl Send for HWNDWrapper