Struct ClientConfig
pub struct ClientConfig {
pub ssh_config_path: String,
pub program: String,
pub arguments: Vec<String>,
pub username_host_placeholder: String,
pub disabled_console_color: u16,
pub highlighted_console_color: u16,
}Expand description
Representation of the client subcommand configurations.
Fields
ssh_config_path: Stringprogram: Stringarguments: Vec<String>List of arguments provided to the program.
Must include the username_host_placeholder.
Example
['-XY', '{{USERNAME_AT_HOST}}']
username_host_placeholder: StringPlaceholder string used to inject <user>@<host> into the list of arguments.
Example
'{{USERNAME_AT_HOST}}'
disabled_console_color: u16Controls back- and foreground colors of the client console window
when the client is in the Disabled state.
Uses the same encoding as DaemonConfig::console_color.
All standard Windows color combinations are available:
FOREGROUND_BLUE: 1
FOREGROUND_GREEN: 2
FOREGROUND_RED: 4
FOREGROUND_INTENSITY: 8
BACKGROUND_BLUE: 16
BACKGROUND_GREEN: 32
BACKGROUND_RED: 64
BACKGROUND_INTENSITY: 128 \
Example
Default-grey font on muted dark-grey background:
4 + 2 + 1 + 128 = 135
highlighted_console_color: u16Controls back- and foreground colors of the client console window while it is the currently selected window in the daemon’s enable/disable submenu.
Uses the same encoding as DaemonConfig::console_color.
All standard Windows color combinations are available:
FOREGROUND_BLUE: 1
FOREGROUND_GREEN: 2
FOREGROUND_RED: 4
FOREGROUND_INTENSITY: 8
BACKGROUND_BLUE: 16
BACKGROUND_GREEN: 32
BACKGROUND_RED: 64
BACKGROUND_INTENSITY: 128 \
Example
Bright-white font on blue background:
4 + 2 + 1 + 8 + 16 = 31