Function send_pid_handshake
async fn send_pid_handshake(named_pipe_client: &NamedPipeClient)Expand description
Send this process’s id over the pipe to the daemon as a 4 byte little-endian sequence.
The daemon uses the PID to match the pipe connection to the correct
crate::daemon Client entry. Without this handshake the daemon will
not forward any input records.
Arguments
named_pipe_client- The connected pipe client to write the PID to.
Panics
Panics if the pipe write fails in a way that cannot be retried.