Function write_framed_message
async fn write_framed_message(server: &NamedPipeServer, frame: &[u8]) -> boolExpand description
Write all of frame to the named pipe server, retrying partial
writes and WouldBlock results until the buffer is fully drained.
Returns true on full write, false if the pipe is closed.
Panics
Panics if waiting for the pipe to become writable returns an error.