Struct Client
struct Client {
hostname: String,
window_handle: HWND,
process_handle: HANDLE,
process_id: u32,
pipe_server_state: Arc<Mutex<PipeServerState>>,
}Expand description
Representation of a client
Fields
hostname: StringHostname the client is connect to (or supposed to connect to).
window_handle: HWNDWindow handle to the clients console window.
process_handle: HANDLEProcess handle to the client process.
process_id: u32Process id of the client process.
Used by the pipe server task to correlate which client has connected to it, via a handshake over the named pipe.
pipe_server_state: Arc<Mutex<PipeServerState>>Shared state between this client and its assigned pipe server task.
Populated at Client construction; cloned by the pipe server task upon
successful PID correlation and consulted during input forwarding to
determine whether records should be sent to the client.